package cc.smarnet.gpsdkdemo;

import androidx.appcompat.app.AppCompatActivity;

import android.annotation.SuppressLint;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Color;
import android.os.Bundle;
import android.util.Log;
import android.view.View;

import java.io.IOException;

import cc.smarnet.sdk.Observer;
import cc.smarnet.sdk.command.EscCommand;

public class MainActivity extends AppCompatActivity {

    private static final String TAG = MainActivity.class.getSimpleName();

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

    }

    public void printTest(View view) {
        final EscCommand escCommand = EscCommand.getInstance();
        try {
            escCommand.connect(this, new Observer() {
                @Override
                public void success() {
                    Log.i(TAG, "success");
                    escCommand.addPrintAndFeedLines((byte) 3);
                    // 设置打印居中
                    escCommand.addSelectJustification(EscCommand.JUSTIFICATION.CENTER);
                    // 设置为倍高倍宽
                    escCommand.addSelectPrintModes(EscCommand.FONT.FONTA, EscCommand.ENABLE.OFF, EscCommand.ENABLE.ON, EscCommand.ENABLE.ON, EscCommand.ENABLE.OFF);
                    // 打印文字
                    escCommand.addText("Sample\n");
                    escCommand.addPrintAndLineFeed();

                    /* 打印文字 */
                    // 取消倍高倍宽
                    escCommand.addSelectPrintModes(EscCommand.FONT.FONTA, EscCommand.ENABLE.OFF, EscCommand.ENABLE.OFF, EscCommand.ENABLE.OFF, EscCommand.ENABLE.OFF);
                    // 设置打印左对齐
                    escCommand.addSelectJustification(EscCommand.JUSTIFICATION.LEFT);
                    // 打印文字
                    escCommand.addText("Print text\n");
                    // 打印文字
                    escCommand.addText("Welcome to use SMARNET printer!\n");

                    /* 打印繁体中文 需要打印机支持繁体字库 */
                    String message = "佳博智匯票據打印機\n";
                    escCommand.addText(message, "GB2312");
                    escCommand.addPrintAndLineFeed();

                    /* 绝对位置 具体详细信息请查看GP58编程手册 */
                    escCommand.addText("智汇");
                    escCommand.addSetHorAndVerMotionUnits((byte) 7, (byte) 0);
                    escCommand.addSetAbsolutePrintPosition((short) 6);
                    escCommand.addText("网络");
                    escCommand.addSetAbsolutePrintPosition((short) 10);
                    escCommand.addText("设备");
                    escCommand.addPrintAndLineFeed();

                    /* 打印图片 */
                    // 打印文字
                    escCommand.addText("Print bitmap!\n");
                    Bitmap b = BitmapFactory.decodeResource(getResources(),
                            R.drawable.gprinter);
                    // 打印图片
                    escCommand.addRastBitImage(b, 380, 0);

                    /* 打印一维条码 */
                    // 打印文字
                    escCommand.addText("Print code128\n");
                    escCommand.addSelectPrintingPositionForHRICharacters(EscCommand.HRI_POSITION.BELOW);
                    // 设置条码可识别字符位置在条码下方
                    // 设置条码高度为60点
                    escCommand.addSetBarcodeHeight((byte) 60);
                    // 设置条码单元宽度为1
                    escCommand.addSetBarcodeWidth((byte) 1);
                    // 打印Code128码
                    escCommand.addCODE128(escCommand.genCodeB("SMARNET"));
                    escCommand.addPrintAndLineFeed();

                    /*
                     * QRCode命令打印 此命令只在支持QRCode命令打印的机型才能使用。 在不支持二维码指令打印的机型上，则需要发送二维条码图片
                     */
                    // 打印文字
                    escCommand.addText("Print QRcode\n");
                    // 设置纠错等级
                    escCommand.addSelectErrorCorrectionLevelForQRCode((byte) 0x31);
                    // 设置qrcode模块大小
                    escCommand.addSelectSizeOfModuleForQRCode((byte) 3);
                    // 设置qrcode内容
                    escCommand.addStoreQRCodeData("www.smarnet.cc");
                    escCommand.addPrintQRCode();// 打印QRCode
                    escCommand.addPrintAndLineFeed();

                    // 设置打印左对齐
                    escCommand.addSelectJustification(EscCommand.JUSTIFICATION.CENTER);
                    //打印文字
                    escCommand.addText("Completed!\r\n");

                    escCommand.addPrintAndFeedLines((byte) 8);
                    //切刀
                    escCommand.addCutPaper();
                }

                @Override
                public void fail() {
                    Log.e(TAG, "连接失败");
                }

                @Override
                public void error(Throwable throwable) {
                    Log.e(TAG, "连接出错 - " + throwable.toString());
                }

                @Override
                public void other(int code) {
                    Log.e(TAG, "其它错误 - " + code);
                }
            });
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
}
